/*
 * Copyright (C) 2015 Romain Reuillon
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package romain.database


sealed trait Publication {
  def year: Int
  def authors: Seq[Publication.Author]
}

object Publication {

  case class Author(initial: Option[String], name: String)

  sealed trait Status
  case class Published(
    volume: Option[String] = None,
    issue: Option[String] = None,
    pages: Option[String] = None,
    url: Option[String] = None,
    doi: Option[String] = None,
    issn: Option[String] = None,
    isbn: Option[String] = None) extends Status
  case object Accepted extends Status


  case class Book(authors: Seq[Author], title: String, year: Int, status: Status, editor: Option[String] = None, publisher: Option[String] = None) extends Publication
  case class BookChapter(authors: Seq[Author], title: String, book: String, year: Int, status: Status, publisher: Option[String] = None, editor: Option[String] = None) extends Publication
  case class JournalPublication(authors: Seq[Author], title: String, journal: Journal, year: Int, status: Status) extends Publication
  case class ConferencePublication(authors: Seq[Author], title: String, conference: Conference, year: Int, status: Status, training: Boolean = false) extends Publication
  case class ConferenceCommunication(authors: Seq[Author], title: String, conference: Conference, year: Int, training: Boolean = false, invited: Boolean = false) extends Publication
  case class Training(authors: Seq[Author], title: String, year: Int, place: String, location: Option[String] = None) extends Publication

  case class Conference(name: String, acceptance: Option[Double] = None, place: Option[String] = None)
  case class Journal(name: String, impact: Option[Double] = None, publisher: Option[String] = None)

}

object Publications {

  import Publication._
  implicit def toOption[T](t: T): Option[T] = Some(t)

  def reuillon = Author("R.", "Reuillon")
  def schmitt = Author("C.", "Schmitt")
  def deAldama = Author("R.", "De Aldama")
  def mouret = Author("J.B.", "Mouret")
  def rey = Author("S.", "Rey-Coyrehourcq")
  def pumain = Author("D.", "Pumain")
  def mesmoudi = Author("S.", "Mesmoudi")
  def alvarez = Author("I.", "Alvarez")
  def martin = Author("S.", "Martin")
  def sicard = Author("M.", "Sicard")
  def perrot = Author("N.", "Perrot")
  def traore = Author("M.", "Traore")
  def passerat = Author("J.", "Passerat-Palmbach")
  def hill = Author("D.R.C", "Hill")
  def breton = Author("V.", "Breton")
  def maigne = Author("L.", "Maigne")
  def elBitar = Author("Z.", "El Bitar")
  def rouquier = Author("J.B.", "Rouquier")
  def wuillemin = Author("P.H.", "Wuillemin")
  def cottineau = Author("C.", "Cottineau")
  def chapron = Author("P.", "Chapron")
  def leclaire = Author("M.", "Leclaire")
  def caux = Author("J.", "Caux")
  def lePennec = Author("Y.", "Le Pennec")
  def junier = Author("I.", "Junier")
  def kepes = Author("F.", "Kepes")
  def mazel = Author("C.", "Mazel")
  def lutton = Author("E.", "Lutton")
  def chuffart = Author("F.", "Chuffart")
  def faure = Author("T.", "Faure")
  def dumoulin = Author("N.", "Dumoulin")
  def baudrit = Author("C.", "Baudrit")
  def bourgine = Author("P.", "Bourgine")
  def buvat = Author("I.", "Buvat")
  def tonda = Author("A.", "Tonda")
  def squillero = Author("G.", "Squillero")
  def gouinaud = Author("C.", "Gouinaud")
  def brassebin = Author("M.", "Brassebin")
  def cherel = Author("G.", "Chérel")
  def lokhat = Author("I.", "Lokhat")
  def perret = Author("J.", "Perret")
  def makropoulos = Author("A.", "Makropoulos")
  def robinson = Author("E. C.", "Robinson")
  def parisot = Author("S.", "Parisot")
  def rueckert = Author("D.", "Rueckert")
  def cura = Author("R.", "Cura")
  def banos = Author("A.", "Banos")
  def swerts = Author("E.", "Swerts")
  def vallee = Author("J.", "Vallée")
  def lenechet = Author("F.", "Le Néchet")
  def letexier = Author("M.", "Le Texier")
  def raimbault = Author("J.", "Raimbault")
  def feuillet = Author("T.", "Feuillet")
  def commenges = Author("H.", "Commenges")
  def menai = Author("M.", "Menai")
  def charriere = Author("H.", "Charreire")
  def kesseguyot = Author("E.", "Kesse-Guyot")
  def nazare = Author("J.-A.", "Nazare")
  def hercberg = Author("S.", "Hercberg")
  def oppert  = Author("J.-M.", "Oppert")
  def mayer = Author("K.", "Mayer")
  def sikk = Author("K.", "Sikk")
  def salze = Author("P.", "Salze")
  def perchoux = Author("C.", "Perchoux")
  def arduin = Author("H.", "Arduin")
  def delay = Author("E.", "Delay")
  def brugiere = Author("A.", "Brugière")

  def widyastuti = Author("K.", "Widyastuti")
  def abdussalam = Author("W.", "Abdussalam")
  def nasir = Author("D.", "Nasir")
  def harrsion = Author("M. E.", "Harrison")
  def morroghBernard = Author("H.", "Morrogh-Bernard")
  def imron = Author("M. A.", "Imron")
  def berger = Author("U.", "Berger")

  val al = Author(None, "et al.")

  def jasss = Journal("Journal of Artificial Societies and Social Simulation (JASSS)", impact = 1.733)

  
  def all = Seq(
    JournalPublication(
      authors = Seq(widyastuti, reuillon, chapron, abdussalam, nasir, harrsion, morroghBernard, imron, berger),
      title = "Assessing the impact of forest structure disturbances on the arboreal movement and energetics of orangutans—An agent-based modeling approach",
      journal = Journal("Frontier in Ecology and Evolution"),
      status = Published(doi = "10.3389/fevo.2022.983337"),
      year = 2022
    ),
    ConferenceCommunication(
      authors = Seq(chapron, leclaire, delay, reuillon),
      conference = Conference("UGI-IGU Paris"),
      title = "Co-construire et formaliser les relations foncières dans le bassin arrachidier au Sénégal - une question de temps et d’espace",
      year = 2022
    ),
    ConferenceCommunication(
      authors = Seq(chapron, delay, leclaire, reuillon),
      conference = Conference("FRCCS 2022"),
      title = "Co-construire un modèle de simulation et son exploration : les pratiques des agro-pasteurs de Diohine",
      year = 2022
    ),
    ConferenceCommunication(
      authors = Seq(reuillon),
      conference = Conference("DAFNI Roadshow - Urban models now on DAFNI!"),
      title = "OpenMOLE, an essential software to face Zombie outbreaks",
      year = 2021
    ),
    ConferenceCommunication(
      authors = Seq(vallee, cottineau, perret, reuillon, rey),
      conference = Conference("Séance thématique de l’Académie des technologies"),
      title = "La modélisation à l’épreuve des événements sanitaires, sociaux et environnementaux",
      year = 2021
    ),
    ConferenceCommunication(
      authors = Seq(reuillon, brugiere),
      conference = Conference("GAMA DAYS 2021"),
      title = "Coupling GAMA with OpenMole to easily explore agent-based models in HPC environment",
      year = 2021
    ),
    ConferenceCommunication(
      authors = Seq(arduin, delay, leclaire, reuillon),
      conference = Conference("JDEV 2020, T7 : Modélisation des systèmes complexes sociaux-spatiaux. Modéliser. Simuler. Coupler et alimenter les modèles par des données hétérogènes. Les explorer par le calcul"),
      title = "Covprehention, Exploration de modèles : outils, posture, méthodes",
      year = 2020
    ),
    ConferenceCommunication(
      authors = Seq(leclaire, reuillon),
      conference = Conference("JIEM 2019 : Journées Ifremer - Réseau Mexico - GDR Ecostat - GDR MascotNum"),
      title = "OpenMOLE pour l'étude des modèles de systèmes complexes",
      year = 2019
    ),
    JournalPublication(
      authors = Seq(raimbault, cottineau, letexier, lenechet, reuillon),
      title = "Space Matters: Extending Sensitivity Analysis to Initial Spatial Conditions in Geosimulation Models",
      journal = jasss,
      status = Published(issue = "22", doi = "DOI: 10.18564/jasss.4136"),
      year = 2019
    ),
    JournalPublication(
      authors = Seq(feuillet, commenges, menai, salze, perchoux, reuillon, al),
      title = "A massive geographically weighted regression model of walking-environment relationships",
      journal = Journal("Journal of transport geography"),
      status = Published(issue = "68", pages = "118-129"),
      year = 2018
    ),
    ConferenceCommunication(
      authors = Seq(mayer, sikk, reuillon, leclaire),
      title = "Analyzing models with OpenMOLE platform: a roadmap",
      conference = Conference("Saltelite SimExplo 2019: Satellite Session: New methods and epistemologies to explore simulation models",  place = "Singapore"),
      year = 2019
    ),
    ConferenceCommunication(
      authors = Seq(cottineau, perret, reuillon, rey, vallee),
      title = "H24 : un modèle multi-agents pour explorer les effets de la ségrégation au cours de la journée sur les inégalités de comportements alimentaires en Ile-de-France.",
      conference = Conference("Quatorzièmes Rencontres ThéoQuant", place = "Besançon, France"),
      year = 2019
    ),
    ConferenceCommunication(
      authors = Seq(cottineau, perret, reuillon, rey, vallee),
      title = "H24 : un modèle multi-agents pour explorer les effets de la ségrégation au cours de la journée sur les inégalités de comportements alimentaires en Ile-de-France",
      conference = Conference("Séminaire Alimentation et Sciences Sociales de l’EHESS", place = "Paris, France"),
      year = 2018
    ),
    ConferencePublication(
      authors = Seq(cottineau, perret, reuillon, rey, vallee),
      title = "An agent-based model to investigate the effects of social segregation around the clock on social disparities in dietary behaviour",
      conference = Conference("CIST2018 - Représenter les territoires / Representing territories, CIST", place = "Rouen, France"),
      status = Published(),
      year = 2018,
    ),
    ConferenceCommunication(
      authors = Seq(cottineau, perret, reuillon, rey, vallee),
      title = "H24 : un modèle multi-agents pour explorer les effets de la ségrégation au cours de la journée sur les inégalités de comportements alimentaires en Ile-de-France",
      conference = Conference("Séminaire Alimentation et Sciences Sociales de l’EHESS"),
      year = 2018
    ),
    ConferenceCommunication(
      authors = Seq(reuillon, leclaire),
      title = "Reproducible model evaluation with OpenMOLE",
      conference = Conference("ExpeNUM: apprendre à réaliser des campagnes de calcul reproductibles pour des applications de modélisation, simulations paramétriques, benchmarking, analyses de données numériques ou expérimentales"),
      year = 2018
    ),
    ConferencePublication(
      authors = Seq(brassebin, chapron, cherel, leclaire, lokhat, perret, reuillon),
      title = "Apports des méthodes d’exploration et de distribution appliquées à la simulation des droits à bâtir",
      conference = Conference("Colloque International de Géomatique et d’Analyse Spatiale (SAGEO 2017)", place = "Rouen, France"),
      status = Published(url = "https://hal.archives-ouvertes.fr/SAGEO2017/hal-01650530v1"),
      year = 2017
    ),
    ConferenceCommunication(
      authors = Seq(feuillet, commenges, menai, charriere, kesseguyot, reuillon, nazare, hercberg, oppert),
      title = "Why do I walk here? Computing a large scale GWR for hierarchising the environmental correlates of walking in France",
      conference = Conference("European Colloquium of Theoretical and Quantitative Geography (ECTQG)", place = "Leeds, UK"),
      year = 2017
    ),
    ConferenceCommunication(
      authors = Seq(cottineau, raimbault, letexier, lenechet, reuillon),
      title = "Initial spatial conditions in simulation models: the missing leg of sensitivity analyses?",
      conference = Conference("GeoComputation"),
      year = 2017
    ),
    ConferenceCommunication(
      authors = Seq(chapron, brassebin, perret, reuillon),
      title = "Exploration de l’influence de la réglementation urbaine locale sur la morphologie des formes bâties par simulation distribuée",
      conference = Conference("13e Rencontres de Théo Quant", place = "Besançon, France"),
      year = 2017
    ),
    ConferenceCommunication(
      authors = Seq(cottineau, cherel, reuillon, chapron, pumain),
      year = 2015,
      title = "Un modèle, et après ? Exploration de dynamiques urbaines simulées avec MARIUS",
      conference = Conference("XIIe Rencontres ThéoQuant", place = "Besançon, France")
    ),
    ConferenceCommunication(
      authors = Seq(cottineau, lenechet, letexier, raimbault, reuillon),
      year = 2015,
      title = "Revisiting some geography classics with spatial simulation",
      conference = Conference("European Colloquium of Theoretical and Quantitative Geography (ECTQG) 2015", place = "Bari, Italy")
    ),
    ConferenceCommunication(
      authors = Seq(cottineau, perret, reuillon, rey, vallee),
      title = "An agent-based model to investigate the effects of social segregation around the clock on social disparities in dietary behaviour",
      conference = Conference("4e colloque international du Collège international des sciences du territoire CIST", place = "Rouen"),
      year = 2018
    ),
    ConferenceCommunication(
      authors = Seq(chapron, cottineau, reuillon),
      year = 2015,
      title = "Building and exploring systems of cities models via distributed computing",
      conference = Conference("Conference on Complex Systems", place = "Tempa, USA")
    ),
    ConferenceCommunication(
      authors = Seq(reuillon, leclaire, passerat),
      title = "Distributed neurosciences with OpenMOLE",
      conference = Conference("From open data to multi-level cerebral dynamics"),
      year = 2015
    ),
    ConferenceCommunication(
      authors = Seq(reuillon, leclaire),
      title = "Communauté de logiciel libre en recherche: l’exemple d’OpenMOLE",
      conference = Conference("Journée Logiciel Libre de l’INRA"),
      year = 2017
    ),
    ConferenceCommunication(
      authors = Seq(reuillon),
      title = "Towards Computer Assisted Modeling",
      conference = Conference("ERC GeoDiverCity International Workshop Theories and models of urbanization"),
      year = 2017,
      invited = true
    ),
    Book(
      authors = Seq(pumain, reuillon, cherel, cottineau, cura, leclaire, rey, banos, schmitt, swerts),
      title = "Urban Dynamics and Simulation Models",
      year = 2017,
      status = Published(doi ="10.1007/978-3-319-46497-8", isbn = "ISBN 978-3-319-46497-8", pages = "123"),
      editor = "Springer"
    ),
    JournalPublication(
      title = "Reproducible large-scale neuroimaging studies with the OpenMOLE workflow management system",
      authors = Seq(passerat, reuillon, leclaire, makropoulos, robinson, parisot, rueckert),
      journal = Journal("Frontiers in Neuroinformatics"),
      status = Published(issn = "1662-5196", pages = "21", volume = "11", doi = "10.3389/fninf.2017.00021"),
      year = 2017
    ),
    Training(
      authors = Seq(reuillon, leclaire),
      title = "OpenMOLE 101",
      place = "Formation auprès du Master Erasmum Mundus on Complex Systems",
      year = 2015
    ),
    Training(
      authors = Seq(reuillon, leclaire, passerat),
      title = "OpenMOLE",
      place = "Formation au Centre for Advanced Spatial Analysis (CASA)",
      year = 2015
    ),
    Training(
      authors = Seq(reuillon, leclaire, passerat),
      title = "OpenMOLE",
      place = "Formation au laboratoire Biomedia - Imperial College",
      year = 2015
    ),
    Training(
      authors = Seq(reuillon, leclaire),
      title = "OpenMOLE a DSL to explore complex-system models",
      place = "Formation au laboratoire GRETha (Groupe de Recherche en Économie Théorique et Appliquée) – UMR 5113",
      year = 2013
    ),
    Training(
      authors = Seq(reuillon, leclaire),
      title = "Model calibration with OpenMOLE",
      place = "Formation au laboratoire ThéMA (Théoriser et Modéliser pour Aménager) – UMR 6049",
      year = 2013
    ),
    Training(
      authors = Seq(reuillon, leclaire),
      title = "Intensive computation with OpenMOLE",
      place = "Formation au laboratoire DIVERSE (DIVERsity centric Software Engineering) - INRIA",
      year = 2014
    ),
    Training(
      authors = Seq(reuillon, leclaire),
      title = "Running Gama Agent-based models with OpenMOLE",
      year = 2014,
      place = "Atelier SMAsHpc Simulation Multi-Agents et Calcul Haute Performance"
    ),
    Training(
      authors = Seq(reuillon, leclaire),
      title = "OpenMOLE tutorial",
      place = "Rencontres RNSC 2014 (Réseau National des Systèmes Complexes)",
      year = 2014
    ),
    Training(
      authors = Seq(reuillon, leclaire),
      title = "Experimentation on complex-system models with OpenMOLE",
      place = "Rencontres RNSC 2013 (Réseau National des Systèmes Complexes)",
      year = 2013
    ),
    Training(
      authors = Seq(reuillon, leclaire),
      title = "Speed up your Data processing with OpenMOLE",
      year = 2013,
      place = "Brain Hack"
    ),
    Training(
      authors = Seq(reuillon, leclaire),
      title = "OpenMOLE: run your code indifferently on your computer, a cluster, a grid...",
      place = "JDEV (Journées nationales du Développement Logiciel)",
      year = 2013
    ),
    ConferenceCommunication(
      authors = Seq(rey, schmitt, rouquier, leclaire, pumain),
      title = "La preuve par le calcul intensif pour des modèles de simulation et géographie",
      conference = Conference("Rencontres interdisciplinaires sur les systèmes complexes naturels et artificiels: La preuve et ses moyens"),
      year = 2013
    ),
    ConferenceCommunication(
      authors = Seq(chapron, cottineau, reuillon, rey, schmitt),
      title = "Construction inter-disciplinaire de multi-modélisation pour l'étude des systèmes de villes",
      conference = Conference("Rencontres interdisciplinaires sur les systèmes complexes naturels et artificiels: Multi-trans-interdisciplinarité"),
      year = 2014
    ),
    ConferenceCommunication(
      authors = Seq(reuillon, leclaire),
      title = "OpenMOLE for Complex Systems models",
      conference = Conference("ICCSA 2014: The 4th International Conference on Complex Systems and Applications"),
      year = 2014,
      training = true
    ),
    ConferenceCommunication(
      authors = Seq(reuillon, leclaire),
      title = "On the road to the Grid",
      conference = Conference("EGI User Forum"),
      year = 2013,
      training = true
    ),
    ConferenceCommunication(
      authors = Seq(reuillon, leclaire),
      title = "Is the grid driving you crazy? Relax! Openmole makes it easy!",
      conference = Conference("EGI Technical Forum"),
      year = 2013,
      training = true
    ),
    ConferenceCommunication(
      authors = Seq(reuillon, leclaire),
      title = "The calibration of complex-system models with OpenMOLE",
      conference = Conference("ECCS (European Conference on Complex Systems"),
      year = 2013
    ),
    ConferenceCommunication(
      authors = Seq(leclaire, reuillon),
      title = "The calibration of complex system models with OpenMOLE",
      conference = Conference("European Colloquium in Theoretical and Quantitative Geography"),
      year = 2013
    ),
    ConferenceCommunication(
      authors = Seq(leclaire, reuillon),
      title = "Simpuzzle/Janet Tools or How to Build a Step by Step Modular ABM?",
      year = 2014,
      conference = Conference("Association of American Geographers (AAG) 2014")
    ),
    BookChapter(
      authors = Seq(brassebin, perret, reuillon),
      title = "Stochastic Buildings Generation to Assist in the Design of Right to Build Plans",
      book = "Advances in 3D Geoinformation",
      year = 2017,
      status = Published(pages = "373--384", isbn = "978-3-319-25691-7", doi = "10.1007/978-3-319-25691-7_21", url = "https://doi.org/10.1007/978-3-319-25691-7_21"),
      publisher = "Springer",
      editor = "Abdul-Rahman, Alias"
    ),
    JournalPublication(
      authors = Seq(cottineau, reuillon, chapron, rey, pumain),
      title = "A Modular Modelling Framework for Hypotheses Testing in the Simulation of Urbanisation",
      journal = Journal("Systems"),
      status = Published(volume = "3", issue = "4", pages = "348", url = "http://www.mdpi.com/2079-8954/3/4/348", issn = "2079-8954",  doi = "10.3390/systems3040348"),
      year = 2015
    ),
    JournalPublication(
      authors = Seq(cherel, cottineau, reuillon),
      journal = Journal("PLOS ONE", publisher = "Public Library of Science"),
      title = "Beyond Corroboration: Strengthening Model Validation by Looking for Unexpected Patterns",
      year = 2015,
     status = Published(volume = "10", url = "https://doi.org/10.1371/journal.pone.0138212", pages = "1-28", issue = "9", doi = "10.1371/journal.pone.0138212"),
    ),
    JournalPublication(
      authors = Seq(rouquier, alvarez, reuillon, wuillemin),
      title = "A kd-tree algorithm to discover the boundary of a blackbox hypervolume",
      journal = Journal("Annals of Mathematics and Artificial Intelligence", impact = 0.488),
      year = 2015,
      status = Published(volume = "75", issue = "3-4", pages = "335-350")
    ),
    JournalPublication(
      authors = Seq(cottineau, chapron, reuillon),
      title = "Growing Models from the bottom up, An evaluation-based incremental modeling method (EBIMM) applied to systems of cities",
      journal = jasss,
      year = 2015,
      status = Published(url = "http://jasss.soc.surrey.ac.uk/18/4/9.html", volume = "18", issue = "4")
    ),
    JournalPublication(
      authors = Seq(reuillon, schmitt, deAldama, mouret),
      title = "A New Method to Evaluate Simulation Models: The Calibration Profile (CP) Algorithm",
      journal = jasss,
      year = 2015,
      status = Published(url = "http://jasss.soc.surrey.ac.uk/18/1/12.html", volume = "18", issue = "1")
    ),
    ConferencePublication(
      authors = Seq(reuillon, leclaire, passerat),
      conference =  Conference(name = "2015 International Conference on High Performance Computing Simulation (HPCS)"),
      title = "Model exploration using OpenMOLE a workflow engine for large scale distributed design of experiments and parameter tuning",
      year= 2015,
      status = Published(pages= "1-8", doi= "10.1109/HPCSim.2015.7237015"),
      training = true
    ),
    JournalPublication(
      authors = Seq(schmitt, rey, reuillon, pumain),
      title = "Half a billion simulations: Evolutionary algorithms and distributed computing for calibrating the SimpopLocal geographical model",
      journal = Journal("Environment and Planning B", impact = 1.084),
      year = 2015,
      status = Published(doi = "doi:10.1068/b130064p")
    ),
    JournalPublication(
      authors = Seq(mesmoudi, alvarez, martin, reuillon, sicard, perrot),
      title = "A mathematical approach coupling geometric analysis and viability theory for system exploration.Application to a food living system",
      journal = Journal("Journal of Process Control", impact = 2.179),
      year = 2014,
      status = Published(volume = "24", issue = "2", pages = "18-28")
    ),
    JournalPublication(
      authors = Seq(reuillon, leclaire, rey),
      title = "OpenMOLE, a workflow engine specifically tailored for the distributed exploration of simulation models",
      journal = Journal("Future Generation Computer Systems", impact = 2.639),
      year = 2013,
      status = Published(volume = "29", issue = "8", pages = "1981-1990")
    ),
    JournalPublication(
      authors = Seq(reuillon, traore, passerat, hill),
      title = "Parallel stochastic simulations with rigorous distribution of pseudo-random numbers with DistMe: Application to life science simulations",
      journal = Journal("Concurency and computation  : Practice and experience", impact = 0.784),
      year = 2012,
      status = Published(volume = "24", issue = "7", pages = "723-738")
    ),
    ConferencePublication(
      authors = Seq(alvarez, deAldama, martin, reuillon),
      title = "Assessing the resilience of bilingual societies: coupling viability and active learning with kd-tree",
      conference = Conference("Twenty-Third International Joint Conference on Artificial Intelligence (IJCAI)", acceptance = 0.28),
      year = 2013,
      status = Published(pages = "2776-2782", isbn = "978-1-57735-633-2")
    ),
    ConferencePublication(
      authors = Seq(passerat, caux, lePennec, reuillon, junier, kepes),
      title = "Parallel Stepwise Stochastic Simulation: Harnessing GPUs to Explore Possible Futures States of a Chromosome Folding Model Thanks to the Possible Futures Algorithm (PFA)",
      conference = Conference(" ACM Principles of Advanced Discrete Simulation (PADS)", acceptance = 0.39),
      year = 2013,
      status = Published(pages = "169-178", isbn = "978-1-4503-1920-1", doi = "10.1145/2486092.2486114")
    ),
    ConferencePublication(
      authors = Seq(passerat, reuillon, mazel, hill),
      title = "Prototyping Parallel Simulations on Manycore Architectures Using Scala: A Case Study",
      conference = Conference("IEEE ACM High Performance Computing and Simulation (HPCS) proceedings", acceptance = 0.29),
      year = 2013,
      status = Published(pages = "405-412", doi = "10.1109/HPCSim.2013.6641447")
    ),
    ConferencePublication(
      authors = Seq(tonda, lutton, reuillon, squillero),
      title = "Bayesian network structure learning from limited datasets through graph evolution",
      conference = Conference("European Conference on Genetic Programming", acceptance = 0.39),
      year = 2012,
      status = Published(pages = "254-265")
    ),
    ConferencePublication(
      authors = Seq(perrot, mesmoudi, reuillon, lutton, alvarez),
      title = "The complex system science for optimal strategy of management of a food system: the camembert cheese ripening",
      conference = Conference("International Congress on Engineering and Food"),
      year = 2011,
      status = Published(pages = "325-331")
    ),
    ConferencePublication(
      authors = Seq(mesmoudi, perrot, reuillon, bourgine, lutton),
      title = "Optimal Viable Path Search for a Cheese Ripening Process Using a Multi-Objective EA",
      conference = Conference("International Conference on Evolutionary Computation"),
      year = 2010,
      status = Published(pages = "225-230")
    ),
    ConferencePublication(
      authors = Seq(reuillon, chuffart, leclaire, faure, dumoulin, hill),
      title = "Declarative task delegation in openmole",
      conference = Conference("IEEE International Conference on High Performance Computing and Simulation"),
      year = 2010,
      status = Published(pages = "55-62")
    ),
    ConferencePublication(
      authors = Seq(reuillon, hill, gouinaud, elBitar, breton, buvat),
      title = "Monte Carlo Simulation With The GATE Software Using Grid Computing",
      conference = Conference("ACM - NOTERE, New Technologies in Distributed Systems"),
      year = 2008,
      status = Published(pages = "201-204")
    ),
    ConferencePublication(
      authors = Seq(reuillon, hill, elBitar, breton),
      title = "A Java Based Toolbox for the Distribution of Parallel Monte Carlo Simulations. Application to Nuclear Medicine Using the GATE Simulation Package",
      conference = Conference("International Conference on Parallel and Distributed Processing Techniques and Applications"),
      year = 2007,
      status = Published(pages = "122-136")
    ),
    ConferencePublication(
      authors = Seq(reuillon, hill),
      title = "DistMe: A Generic Toolkit for Stochastic Simulation Distribution",
      conference = Conference("European Simulation & Modelling Conference"),
      year = 2006,
      status = Published(pages = "127-133")
    ),
    ConferencePublication(
      authors = Seq(reuillon, hill),
      title = "Testing unrolling optimization technique for quasi-random numbers",
      conference = Conference("Open International Conference on Modeling & Simulation"),
      year = 2005,
      status = Published(pages = "355-362")
    ),
    ConferenceCommunication(
      authors = Seq(sicard, perrot, baudrit, reuillon, bourgine, alvarez, martin),
      title = "The viability theory to control complex food processes",
      conference = Conference("European Conference on Complex Systems"),
      year = 2009
    ),
    JournalPublication(
      authors = Seq(breton, reuillon, al),
      title = "Innovative In Silico Approaches to Address Avian Flu Using Grid Technology",
      journal = Journal("Infectious Disorders-Drug Targets", impact = 3.850),
      year = 2009,
      status = Published(volume = "9", issue = "3", pages = "358-365")
    ),
    JournalPublication(
      authors = Seq(reuillon, hill, elBitar, breton),
      title = "Rigorous distribution of stochastic simulations using the DistMe toolkit",
      journal = Journal("Transaction on Nuclear Science", impact = 1.455),
      year = 2008,
      status = Published(volume = "55", issue = "1", pages = "595-603")
    ),
    JournalPublication(
      authors = Seq(maigne, reuillon, al),
      title = "Parallelization Of Monte Carlo Simulations And Submission To A Grid Environment",
      journal = Journal("Parallel processing letters", impact = 0.400),
      year = 2004,
      status = Published(volume = "14", issue = "2", pages = "177-196")
    )
  )

}

//object Pages {
//
//  object sect extends Section()
//
//  import Publications._
//
//  def authors(a: Seq[Author]): Frag =
//    a.map {
//      case a if a == reuillon => b(reuillon.name)
//      case a => a.name: Frag
//    }.reduceLeft((l, r) => Seq[Frag](l, ", ", r))
//
//  def status(s: Status): Frag =
//    s match {
//      case Accepted => "accepted"
//      case s: Published =>
//        val infos = Seq[Option[Frag]](s.volume.map("volume " + _), s.issue.map("issue " + _), s.pages.map("pages " + _), s.doi.map("doi: " + _), s.url.map(_.toString))
//        infos.flatten.reduceLeft((l, r) => Seq[Frag](l, ", ", r))
//    }
//
//  def journal(j: Journal): Frag =
//    Seq(j.name) ++ j.impact.map("(IF: " + _ + ")")
//
//  def publication(p: Publication): Frag =
//    p match {
//      case p: JournalPublication => Seq[Frag](authors(p.authors), ": ", i(p.title), " published in ", p.journal.name, ", ", status(p.status), ".")
//      case p: ConferencePublication => Seq[Frag](authors(p.authors), ": ", i(p.title), " published in proceedings of ", p.conference.name, ", ", status(p.status), ".")
//      case p: ConferenceCommunication => authors(p.authors)
//    }
//
//  def year(ps: Seq[Publication], y: Int) = {
//    def row(y: Option[Int], p: Publication) =
//      div(`class` := "row", id := "publication")(div(`class` := "col-md-1")(y), div(`class` := "col-md-11")(publication(p)))
//
//    Seq(row(Some(y), ps.head)) ++ ps.tail.map(row(None, _))
//  }
//
//  def publications: Frag = {
//    def toArray(ps: Seq[Publication]) =
//      ps.groupBy(_.year).toSeq.sortBy(_._1).reverse.flatMap {
//        case (y, js) => year(js, y)
//      }
//
//    val journals = toArray(Publications.all.collect { case j: Publications.JournalPublication => j })
//    val conferences = toArray(Publications.all.collect { case j: Publications.ConferencePublication => j })
//
//    Seq[Frag](
//      sect("Peer reviewed international journal publications")(journals),
//      sect("Peer reviewed international conference publications")(conferences)
//    )
//  }
//
//  def resume = p(
//    """I am a researcher in software engineering. I work for the CNRS at both the Geographie-citées and the Complex Systems Institutes of Paris. I obtained a PhD in 2008 on distributed stochastic simulations. Since I work on enabling distributed computing and high-performance computing for modeling. I manage the development of the OpenMOLE plate-form for large scale model experiments.""".stripMargin)
//
//  def index = new Page {
//    def location: String = "index.html"
//    def content: Frag =
//      Seq(
//        resume,
//        sect("Publications")(publications)
//      )
//  }
//
//  def all = Seq(index)
//
//}

//object SiteGeneration extends App {
//
//  val site = new scalatex.site.Site {
//
//    override def siteCss: Set[Path] = super.siteCss + Path.root / 'romain / "romain.css"
//
//    override def headFrags: Seq[Frag] = super.headFrags ++ Seq(
//      meta(charset := "UTF-8"),
//      link(rel := "stylesheet", href := "https://maxcdn.bootstrapcdn.com/bootstrap/3.3.2/css/bootstrap.min.css"),
//      script(src := "https://maxcdn.bootstrapcdn.com/bootstrap/3.3.2/js/bootstrap.min.js")
//    )
//
//    override def content: Map[String, Frag] = Pages.all.map(p => p.location -> p.content).toMap
//  }
//
//  site.renderTo(Path(args(0)))
//}
